"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class Coin(google.protobuf.message.Message):
    """Coin defines a token with a denomination and an amount.

    NOTE: The amount field is an Int which implements the custom method
    signatures required by gogoproto.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DENOM_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    denom: typing.Text
    amount: typing.Text
    def __init__(self,
        *,
        denom: typing.Text = ...,
        amount: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount",b"amount","denom",b"denom"]) -> None: ...
global___Coin = Coin

class DecCoin(google.protobuf.message.Message):
    """DecCoin defines a token with a denomination and a decimal amount.

    NOTE: The amount field is an Dec which implements the custom method
    signatures required by gogoproto.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DENOM_FIELD_NUMBER: builtins.int
    AMOUNT_FIELD_NUMBER: builtins.int
    denom: typing.Text
    amount: typing.Text
    def __init__(self,
        *,
        denom: typing.Text = ...,
        amount: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount",b"amount","denom",b"denom"]) -> None: ...
global___DecCoin = DecCoin

class IntProto(google.protobuf.message.Message):
    """IntProto defines a Protobuf wrapper around an Int object."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    INT_FIELD_NUMBER: builtins.int
    int: typing.Text
    def __init__(self,
        *,
        int: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["int",b"int"]) -> None: ...
global___IntProto = IntProto

class DecProto(google.protobuf.message.Message):
    """DecProto defines a Protobuf wrapper around a Dec object."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    DEC_FIELD_NUMBER: builtins.int
    dec: typing.Text
    def __init__(self,
        *,
        dec: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dec",b"dec"]) -> None: ...
global___DecProto = DecProto
