# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: oracle/v1beta1/oracle.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1boracle/v1beta1/oracle.proto\x12\x15nibiru.oracle.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x99\x05\n\x06Params\x12+\n\x0bvote_period\x18\x01 \x01(\x04\x42\x16\xf2\xde\x1f\x12yaml:\"vote_period\"\x12_\n\x0evote_threshold\x18\x02 \x01(\tBG\xf2\xde\x1f\x15yaml:\"vote_threshold\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12Y\n\x0breward_band\x18\x03 \x01(\tBD\xf2\xde\x1f\x12yaml:\"reward_band\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12I\n\x1areward_distribution_window\x18\x04 \x01(\x04\x42%\xf2\xde\x1f!yaml:\"reward_distribution_window\"\x12T\n\twhitelist\x18\x05 \x03(\x0b\x32\x1b.nibiru.oracle.v1beta1.PairB$\xf2\xde\x1f\x10yaml:\"whitelist\"\xaa\xdf\x1f\x08PairList\xc8\xde\x1f\x00\x12_\n\x0eslash_fraction\x18\x06 \x01(\tBG\xf2\xde\x1f\x15yaml:\"slash_fraction\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12-\n\x0cslash_window\x18\x07 \x01(\x04\x42\x17\xf2\xde\x1f\x13yaml:\"slash_window\"\x12k\n\x14min_valid_per_window\x18\x08 \x01(\tBM\xf2\xde\x1f\x1byaml:\"min_valid_per_window\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x01\x98\xa0\x1f\x00\"\x8a\x01\n\x04Pair\x12\x1d\n\x04name\x18\x01 \x01(\tB\x0f\xf2\xde\x1f\x0byaml:\"name\"\x12U\n\ttobin_tax\x18\x02 \x01(\tBB\xf2\xde\x1f\x10yaml:\"tobin_tax\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x0c\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"\x9b\x01\n\x1c\x41ggregateExchangeRatePrevote\x12\x1d\n\x04hash\x18\x01 \x01(\tB\x0f\xf2\xde\x1f\x0byaml:\"hash\"\x12\x1f\n\x05voter\x18\x02 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"voter\"\x12-\n\x0csubmit_block\x18\x03 \x01(\x04\x42\x17\xf2\xde\x1f\x13yaml:\"submit_block\":\x0c\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"\xce\x01\n\x19\x41ggregateExchangeRateVote\x12\x81\x01\n\x14\x65xchange_rate_tuples\x18\x01 \x03(\x0b\x32(.nibiru.oracle.v1beta1.ExchangeRateTupleB9\xf2\xde\x1f\x1byaml:\"exchange_rate_tuples\"\xaa\xdf\x1f\x12\x45xchangeRateTuples\xc8\xde\x1f\x00\x12\x1f\n\x05voter\x18\x02 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"voter\":\x0c\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x98\xa0\x1f\x00\"\x9f\x01\n\x11\x45xchangeRateTuple\x12\x1d\n\x04pair\x18\x01 \x01(\tB\x0f\xf2\xde\x1f\x0byaml:\"pair\"\x12]\n\rexchange_rate\x18\x02 \x01(\tBF\xf2\xde\x1f\x14yaml:\"exchange_rate\"\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00:\x0c\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x98\xa0\x1f\x00\x42.Z,github.com/NibiruChain/nibiru/x/oracle/typesb\x06proto3')



_PARAMS = DESCRIPTOR.message_types_by_name['Params']
_PAIR = DESCRIPTOR.message_types_by_name['Pair']
_AGGREGATEEXCHANGERATEPREVOTE = DESCRIPTOR.message_types_by_name['AggregateExchangeRatePrevote']
_AGGREGATEEXCHANGERATEVOTE = DESCRIPTOR.message_types_by_name['AggregateExchangeRateVote']
_EXCHANGERATETUPLE = DESCRIPTOR.message_types_by_name['ExchangeRateTuple']
Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.Params)
  })
_sym_db.RegisterMessage(Params)

Pair = _reflection.GeneratedProtocolMessageType('Pair', (_message.Message,), {
  'DESCRIPTOR' : _PAIR,
  '__module__' : 'oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.Pair)
  })
_sym_db.RegisterMessage(Pair)

AggregateExchangeRatePrevote = _reflection.GeneratedProtocolMessageType('AggregateExchangeRatePrevote', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATEEXCHANGERATEPREVOTE,
  '__module__' : 'oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.AggregateExchangeRatePrevote)
  })
_sym_db.RegisterMessage(AggregateExchangeRatePrevote)

AggregateExchangeRateVote = _reflection.GeneratedProtocolMessageType('AggregateExchangeRateVote', (_message.Message,), {
  'DESCRIPTOR' : _AGGREGATEEXCHANGERATEVOTE,
  '__module__' : 'oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.AggregateExchangeRateVote)
  })
_sym_db.RegisterMessage(AggregateExchangeRateVote)

ExchangeRateTuple = _reflection.GeneratedProtocolMessageType('ExchangeRateTuple', (_message.Message,), {
  'DESCRIPTOR' : _EXCHANGERATETUPLE,
  '__module__' : 'oracle.v1beta1.oracle_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.ExchangeRateTuple)
  })
_sym_db.RegisterMessage(ExchangeRateTuple)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/NibiruChain/nibiru/x/oracle/types'
  _PARAMS.fields_by_name['vote_period']._options = None
  _PARAMS.fields_by_name['vote_period']._serialized_options = b'\362\336\037\022yaml:\"vote_period\"'
  _PARAMS.fields_by_name['vote_threshold']._options = None
  _PARAMS.fields_by_name['vote_threshold']._serialized_options = b'\362\336\037\025yaml:\"vote_threshold\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['reward_band']._options = None
  _PARAMS.fields_by_name['reward_band']._serialized_options = b'\362\336\037\022yaml:\"reward_band\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['reward_distribution_window']._options = None
  _PARAMS.fields_by_name['reward_distribution_window']._serialized_options = b'\362\336\037!yaml:\"reward_distribution_window\"'
  _PARAMS.fields_by_name['whitelist']._options = None
  _PARAMS.fields_by_name['whitelist']._serialized_options = b'\362\336\037\020yaml:\"whitelist\"\252\337\037\010PairList\310\336\037\000'
  _PARAMS.fields_by_name['slash_fraction']._options = None
  _PARAMS.fields_by_name['slash_fraction']._serialized_options = b'\362\336\037\025yaml:\"slash_fraction\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS.fields_by_name['slash_window']._options = None
  _PARAMS.fields_by_name['slash_window']._serialized_options = b'\362\336\037\023yaml:\"slash_window\"'
  _PARAMS.fields_by_name['min_valid_per_window']._options = None
  _PARAMS.fields_by_name['min_valid_per_window']._serialized_options = b'\362\336\037\033yaml:\"min_valid_per_window\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PARAMS._options = None
  _PARAMS._serialized_options = b'\350\240\037\001\230\240\037\000'
  _PAIR.fields_by_name['name']._options = None
  _PAIR.fields_by_name['name']._serialized_options = b'\362\336\037\013yaml:\"name\"'
  _PAIR.fields_by_name['tobin_tax']._options = None
  _PAIR.fields_by_name['tobin_tax']._serialized_options = b'\362\336\037\020yaml:\"tobin_tax\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PAIR._options = None
  _PAIR._serialized_options = b'\350\240\037\000\210\240\037\000\230\240\037\000'
  _AGGREGATEEXCHANGERATEPREVOTE.fields_by_name['hash']._options = None
  _AGGREGATEEXCHANGERATEPREVOTE.fields_by_name['hash']._serialized_options = b'\362\336\037\013yaml:\"hash\"'
  _AGGREGATEEXCHANGERATEPREVOTE.fields_by_name['voter']._options = None
  _AGGREGATEEXCHANGERATEPREVOTE.fields_by_name['voter']._serialized_options = b'\362\336\037\014yaml:\"voter\"'
  _AGGREGATEEXCHANGERATEPREVOTE.fields_by_name['submit_block']._options = None
  _AGGREGATEEXCHANGERATEPREVOTE.fields_by_name['submit_block']._serialized_options = b'\362\336\037\023yaml:\"submit_block\"'
  _AGGREGATEEXCHANGERATEPREVOTE._options = None
  _AGGREGATEEXCHANGERATEPREVOTE._serialized_options = b'\350\240\037\000\210\240\037\000\230\240\037\000'
  _AGGREGATEEXCHANGERATEVOTE.fields_by_name['exchange_rate_tuples']._options = None
  _AGGREGATEEXCHANGERATEVOTE.fields_by_name['exchange_rate_tuples']._serialized_options = b'\362\336\037\033yaml:\"exchange_rate_tuples\"\252\337\037\022ExchangeRateTuples\310\336\037\000'
  _AGGREGATEEXCHANGERATEVOTE.fields_by_name['voter']._options = None
  _AGGREGATEEXCHANGERATEVOTE.fields_by_name['voter']._serialized_options = b'\362\336\037\014yaml:\"voter\"'
  _AGGREGATEEXCHANGERATEVOTE._options = None
  _AGGREGATEEXCHANGERATEVOTE._serialized_options = b'\350\240\037\000\210\240\037\000\230\240\037\000'
  _EXCHANGERATETUPLE.fields_by_name['pair']._options = None
  _EXCHANGERATETUPLE.fields_by_name['pair']._serialized_options = b'\362\336\037\013yaml:\"pair\"'
  _EXCHANGERATETUPLE.fields_by_name['exchange_rate']._options = None
  _EXCHANGERATETUPLE.fields_by_name['exchange_rate']._serialized_options = b'\362\336\037\024yaml:\"exchange_rate\"\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _EXCHANGERATETUPLE._options = None
  _EXCHANGERATETUPLE._serialized_options = b'\350\240\037\000\210\240\037\000\230\240\037\000'
  _PARAMS._serialized_start=109
  _PARAMS._serialized_end=774
  _PAIR._serialized_start=777
  _PAIR._serialized_end=915
  _AGGREGATEEXCHANGERATEPREVOTE._serialized_start=918
  _AGGREGATEEXCHANGERATEPREVOTE._serialized_end=1073
  _AGGREGATEEXCHANGERATEVOTE._serialized_start=1076
  _AGGREGATEEXCHANGERATEVOTE._serialized_end=1282
  _EXCHANGERATETUPLE._serialized_start=1285
  _EXCHANGERATETUPLE._serialized_end=1444
# @@protoc_insertion_point(module_scope)
