"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class PriceSnapshot(google.protobuf.message.Message):
    """a snapshot of the pricefeed oracle's median price at a given point in time"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PAIR_ID_FIELD_NUMBER: builtins.int
    PRICE_FIELD_NUMBER: builtins.int
    TIMESTAMP_MS_FIELD_NUMBER: builtins.int
    pair_id: typing.Text
    """the token pair"""

    price: typing.Text
    """the median prices of all oracles"""

    timestamp_ms: builtins.int
    """milliseconds since unix epoch"""

    def __init__(self,
        *,
        pair_id: typing.Text = ...,
        price: typing.Text = ...,
        timestamp_ms: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pair_id",b"pair_id","price",b"price","timestamp_ms",b"timestamp_ms"]) -> None: ...
global___PriceSnapshot = PriceSnapshot
