# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: oracle/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from oracle.v1beta1 import oracle_pb2 as oracle_dot_v1beta1_dot_oracle__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aoracle/v1beta1/query.proto\x12\x15nibiru.oracle.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1boracle/v1beta1/oracle.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"2\n\x18QueryExchangeRateRequest\x12\x0c\n\x04pair\x18\x01 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"b\n\x19QueryExchangeRateResponse\x12\x45\n\rexchange_rate\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x1b\n\x19QueryExchangeRatesRequest\"z\n\x1aQueryExchangeRatesResponse\x12\\\n\x0e\x65xchange_rates\x18\x01 \x03(\x0b\x32(.nibiru.oracle.v1beta1.ExchangeRateTupleB\x1a\xaa\xdf\x1f\x12\x45xchangeRateTuples\xc8\xde\x1f\x00\".\n\x14QueryTobinTaxRequest\x12\x0c\n\x04pair\x18\x01 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"Z\n\x15QueryTobinTaxResponse\x12\x41\n\ttobin_tax\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\x18\n\x16QueryTobinTaxesRequest\"s\n\x17QueryTobinTaxesResponse\x12X\n\x0btobin_taxes\x18\x01 \x03(\x0b\x32\x1b.nibiru.oracle.v1beta1.PairB&\xf2\xde\x1f\x12yaml:\"tobin_taxes\"\xaa\xdf\x1f\x08PairList\xc8\xde\x1f\x00\"\x15\n\x13QueryActivesRequest\"\'\n\x14QueryActivesResponse\x12\x0f\n\x07\x61\x63tives\x18\x01 \x03(\t\"\x19\n\x17QueryVoteTargetsRequest\"0\n\x18QueryVoteTargetsResponse\x12\x14\n\x0cvote_targets\x18\x01 \x03(\t\"@\n\x1cQueryFeederDelegationRequest\x12\x16\n\x0evalidator_addr\x18\x01 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"4\n\x1dQueryFeederDelegationResponse\x12\x13\n\x0b\x66\x65\x65\x64\x65r_addr\x18\x01 \x01(\t\";\n\x17QueryMissCounterRequest\x12\x16\n\x0evalidator_addr\x18\x01 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"0\n\x18QueryMissCounterResponse\x12\x14\n\x0cmiss_counter\x18\x01 \x01(\x04\"@\n\x1cQueryAggregatePrevoteRequest\x12\x16\n\x0evalidator_addr\x18\x01 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"u\n\x1dQueryAggregatePrevoteResponse\x12T\n\x11\x61ggregate_prevote\x18\x01 \x01(\x0b\x32\x33.nibiru.oracle.v1beta1.AggregateExchangeRatePrevoteB\x04\xc8\xde\x1f\x00\"\x1f\n\x1dQueryAggregatePrevotesRequest\"w\n\x1eQueryAggregatePrevotesResponse\x12U\n\x12\x61ggregate_prevotes\x18\x01 \x03(\x0b\x32\x33.nibiru.oracle.v1beta1.AggregateExchangeRatePrevoteB\x04\xc8\xde\x1f\x00\"=\n\x19QueryAggregateVoteRequest\x12\x16\n\x0evalidator_addr\x18\x01 \x01(\t:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"l\n\x1aQueryAggregateVoteResponse\x12N\n\x0e\x61ggregate_vote\x18\x01 \x01(\x0b\x32\x30.nibiru.oracle.v1beta1.AggregateExchangeRateVoteB\x04\xc8\xde\x1f\x00\"\x1c\n\x1aQueryAggregateVotesRequest\"n\n\x1bQueryAggregateVotesResponse\x12O\n\x0f\x61ggregate_votes\x18\x01 \x03(\x0b\x32\x30.nibiru.oracle.v1beta1.AggregateExchangeRateVoteB\x04\xc8\xde\x1f\x00\"\x14\n\x12QueryParamsRequest\"J\n\x13QueryParamsResponse\x12\x33\n\x06params\x18\x01 \x01(\x0b\x32\x1d.nibiru.oracle.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\x32\xdc\x11\n\x05Query\x12\xac\x01\n\x0c\x45xchangeRate\x12/.nibiru.oracle.v1beta1.QueryExchangeRateRequest\x1a\x30.nibiru.oracle.v1beta1.QueryExchangeRateResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/nibiru/oracle/v1beta1/pairs/{pair}/exchange_rate\x12\xa9\x01\n\rExchangeRates\x12\x30.nibiru.oracle.v1beta1.QueryExchangeRatesRequest\x1a\x31.nibiru.oracle.v1beta1.QueryExchangeRatesResponse\"3\x82\xd3\xe4\x93\x02-\x12+/nibiru/oracle/v1beta1/pairs/exchange_rates\x12\x9c\x01\n\x08TobinTax\x12+.nibiru.oracle.v1beta1.QueryTobinTaxRequest\x1a,.nibiru.oracle.v1beta1.QueryTobinTaxResponse\"5\x82\xd3\xe4\x93\x02/\x12-/nibiru/oracle/v1beta1/pairs/{pair}/tobin_tax\x12\x9d\x01\n\nTobinTaxes\x12-.nibiru.oracle.v1beta1.QueryTobinTaxesRequest\x1a..nibiru.oracle.v1beta1.QueryTobinTaxesResponse\"0\x82\xd3\xe4\x93\x02*\x12(/nibiru/oracle/v1beta1/pairs/tobin_taxes\x12\x90\x01\n\x07\x41\x63tives\x12*.nibiru.oracle.v1beta1.QueryActivesRequest\x1a+.nibiru.oracle.v1beta1.QueryActivesResponse\",\x82\xd3\xe4\x93\x02&\x12$/nibiru/oracle/v1beta1/pairs/actives\x12\xa1\x01\n\x0bVoteTargets\x12..nibiru.oracle.v1beta1.QueryVoteTargetsRequest\x1a/.nibiru.oracle.v1beta1.QueryVoteTargetsResponse\"1\x82\xd3\xe4\x93\x02+\x12)/nibiru/oracle/v1beta1/pairs/vote_targets\x12\xc0\x01\n\x10\x46\x65\x65\x64\x65rDelegation\x12\x33.nibiru.oracle.v1beta1.QueryFeederDelegationRequest\x1a\x34.nibiru.oracle.v1beta1.QueryFeederDelegationResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/nibiru/oracle/v1beta1/validators/{validator_addr}/feeder\x12\xaf\x01\n\x0bMissCounter\x12..nibiru.oracle.v1beta1.QueryMissCounterRequest\x1a/.nibiru.oracle.v1beta1.QueryMissCounterResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/nibiru/oracle/v1beta1/validators/{validator_addr}/miss\x12\xcb\x01\n\x10\x41ggregatePrevote\x12\x33.nibiru.oracle.v1beta1.QueryAggregatePrevoteRequest\x1a\x34.nibiru.oracle.v1beta1.QueryAggregatePrevoteResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/nibiru/oracle/v1beta1/validators/{validator_addr}/aggregate_prevote\x12\xbe\x01\n\x11\x41ggregatePrevotes\x12\x34.nibiru.oracle.v1beta1.QueryAggregatePrevotesRequest\x1a\x35.nibiru.oracle.v1beta1.QueryAggregatePrevotesResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/nibiru/oracle/v1beta1/validators/aggregate_prevotes\x12\xbf\x01\n\rAggregateVote\x12\x30.nibiru.oracle.v1beta1.QueryAggregateVoteRequest\x1a\x31.nibiru.oracle.v1beta1.QueryAggregateVoteResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/nibiru/oracle/v1beta1/valdiators/{validator_addr}/aggregate_vote\x12\xb2\x01\n\x0e\x41ggregateVotes\x12\x31.nibiru.oracle.v1beta1.QueryAggregateVotesRequest\x1a\x32.nibiru.oracle.v1beta1.QueryAggregateVotesResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/nibiru/oracle/v1beta1/validators/aggregate_votes\x12\x86\x01\n\x06Params\x12).nibiru.oracle.v1beta1.QueryParamsRequest\x1a*.nibiru.oracle.v1beta1.QueryParamsResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/nibiru/oracle/v1beta1/paramsB.Z,github.com/NibiruChain/nibiru/x/oracle/typesb\x06proto3')



_QUERYEXCHANGERATEREQUEST = DESCRIPTOR.message_types_by_name['QueryExchangeRateRequest']
_QUERYEXCHANGERATERESPONSE = DESCRIPTOR.message_types_by_name['QueryExchangeRateResponse']
_QUERYEXCHANGERATESREQUEST = DESCRIPTOR.message_types_by_name['QueryExchangeRatesRequest']
_QUERYEXCHANGERATESRESPONSE = DESCRIPTOR.message_types_by_name['QueryExchangeRatesResponse']
_QUERYTOBINTAXREQUEST = DESCRIPTOR.message_types_by_name['QueryTobinTaxRequest']
_QUERYTOBINTAXRESPONSE = DESCRIPTOR.message_types_by_name['QueryTobinTaxResponse']
_QUERYTOBINTAXESREQUEST = DESCRIPTOR.message_types_by_name['QueryTobinTaxesRequest']
_QUERYTOBINTAXESRESPONSE = DESCRIPTOR.message_types_by_name['QueryTobinTaxesResponse']
_QUERYACTIVESREQUEST = DESCRIPTOR.message_types_by_name['QueryActivesRequest']
_QUERYACTIVESRESPONSE = DESCRIPTOR.message_types_by_name['QueryActivesResponse']
_QUERYVOTETARGETSREQUEST = DESCRIPTOR.message_types_by_name['QueryVoteTargetsRequest']
_QUERYVOTETARGETSRESPONSE = DESCRIPTOR.message_types_by_name['QueryVoteTargetsResponse']
_QUERYFEEDERDELEGATIONREQUEST = DESCRIPTOR.message_types_by_name['QueryFeederDelegationRequest']
_QUERYFEEDERDELEGATIONRESPONSE = DESCRIPTOR.message_types_by_name['QueryFeederDelegationResponse']
_QUERYMISSCOUNTERREQUEST = DESCRIPTOR.message_types_by_name['QueryMissCounterRequest']
_QUERYMISSCOUNTERRESPONSE = DESCRIPTOR.message_types_by_name['QueryMissCounterResponse']
_QUERYAGGREGATEPREVOTEREQUEST = DESCRIPTOR.message_types_by_name['QueryAggregatePrevoteRequest']
_QUERYAGGREGATEPREVOTERESPONSE = DESCRIPTOR.message_types_by_name['QueryAggregatePrevoteResponse']
_QUERYAGGREGATEPREVOTESREQUEST = DESCRIPTOR.message_types_by_name['QueryAggregatePrevotesRequest']
_QUERYAGGREGATEPREVOTESRESPONSE = DESCRIPTOR.message_types_by_name['QueryAggregatePrevotesResponse']
_QUERYAGGREGATEVOTEREQUEST = DESCRIPTOR.message_types_by_name['QueryAggregateVoteRequest']
_QUERYAGGREGATEVOTERESPONSE = DESCRIPTOR.message_types_by_name['QueryAggregateVoteResponse']
_QUERYAGGREGATEVOTESREQUEST = DESCRIPTOR.message_types_by_name['QueryAggregateVotesRequest']
_QUERYAGGREGATEVOTESRESPONSE = DESCRIPTOR.message_types_by_name['QueryAggregateVotesResponse']
_QUERYPARAMSREQUEST = DESCRIPTOR.message_types_by_name['QueryParamsRequest']
_QUERYPARAMSRESPONSE = DESCRIPTOR.message_types_by_name['QueryParamsResponse']
QueryExchangeRateRequest = _reflection.GeneratedProtocolMessageType('QueryExchangeRateRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEXCHANGERATEREQUEST,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryExchangeRateRequest)
  })
_sym_db.RegisterMessage(QueryExchangeRateRequest)

QueryExchangeRateResponse = _reflection.GeneratedProtocolMessageType('QueryExchangeRateResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEXCHANGERATERESPONSE,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryExchangeRateResponse)
  })
_sym_db.RegisterMessage(QueryExchangeRateResponse)

QueryExchangeRatesRequest = _reflection.GeneratedProtocolMessageType('QueryExchangeRatesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEXCHANGERATESREQUEST,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryExchangeRatesRequest)
  })
_sym_db.RegisterMessage(QueryExchangeRatesRequest)

QueryExchangeRatesResponse = _reflection.GeneratedProtocolMessageType('QueryExchangeRatesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEXCHANGERATESRESPONSE,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryExchangeRatesResponse)
  })
_sym_db.RegisterMessage(QueryExchangeRatesResponse)

QueryTobinTaxRequest = _reflection.GeneratedProtocolMessageType('QueryTobinTaxRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTOBINTAXREQUEST,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryTobinTaxRequest)
  })
_sym_db.RegisterMessage(QueryTobinTaxRequest)

QueryTobinTaxResponse = _reflection.GeneratedProtocolMessageType('QueryTobinTaxResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTOBINTAXRESPONSE,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryTobinTaxResponse)
  })
_sym_db.RegisterMessage(QueryTobinTaxResponse)

QueryTobinTaxesRequest = _reflection.GeneratedProtocolMessageType('QueryTobinTaxesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTOBINTAXESREQUEST,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryTobinTaxesRequest)
  })
_sym_db.RegisterMessage(QueryTobinTaxesRequest)

QueryTobinTaxesResponse = _reflection.GeneratedProtocolMessageType('QueryTobinTaxesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTOBINTAXESRESPONSE,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryTobinTaxesResponse)
  })
_sym_db.RegisterMessage(QueryTobinTaxesResponse)

QueryActivesRequest = _reflection.GeneratedProtocolMessageType('QueryActivesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYACTIVESREQUEST,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryActivesRequest)
  })
_sym_db.RegisterMessage(QueryActivesRequest)

QueryActivesResponse = _reflection.GeneratedProtocolMessageType('QueryActivesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYACTIVESRESPONSE,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryActivesResponse)
  })
_sym_db.RegisterMessage(QueryActivesResponse)

QueryVoteTargetsRequest = _reflection.GeneratedProtocolMessageType('QueryVoteTargetsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVOTETARGETSREQUEST,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryVoteTargetsRequest)
  })
_sym_db.RegisterMessage(QueryVoteTargetsRequest)

QueryVoteTargetsResponse = _reflection.GeneratedProtocolMessageType('QueryVoteTargetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYVOTETARGETSRESPONSE,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryVoteTargetsResponse)
  })
_sym_db.RegisterMessage(QueryVoteTargetsResponse)

QueryFeederDelegationRequest = _reflection.GeneratedProtocolMessageType('QueryFeederDelegationRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFEEDERDELEGATIONREQUEST,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryFeederDelegationRequest)
  })
_sym_db.RegisterMessage(QueryFeederDelegationRequest)

QueryFeederDelegationResponse = _reflection.GeneratedProtocolMessageType('QueryFeederDelegationResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFEEDERDELEGATIONRESPONSE,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryFeederDelegationResponse)
  })
_sym_db.RegisterMessage(QueryFeederDelegationResponse)

QueryMissCounterRequest = _reflection.GeneratedProtocolMessageType('QueryMissCounterRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMISSCOUNTERREQUEST,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryMissCounterRequest)
  })
_sym_db.RegisterMessage(QueryMissCounterRequest)

QueryMissCounterResponse = _reflection.GeneratedProtocolMessageType('QueryMissCounterResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMISSCOUNTERRESPONSE,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryMissCounterResponse)
  })
_sym_db.RegisterMessage(QueryMissCounterResponse)

QueryAggregatePrevoteRequest = _reflection.GeneratedProtocolMessageType('QueryAggregatePrevoteRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYAGGREGATEPREVOTEREQUEST,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryAggregatePrevoteRequest)
  })
_sym_db.RegisterMessage(QueryAggregatePrevoteRequest)

QueryAggregatePrevoteResponse = _reflection.GeneratedProtocolMessageType('QueryAggregatePrevoteResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYAGGREGATEPREVOTERESPONSE,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryAggregatePrevoteResponse)
  })
_sym_db.RegisterMessage(QueryAggregatePrevoteResponse)

QueryAggregatePrevotesRequest = _reflection.GeneratedProtocolMessageType('QueryAggregatePrevotesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYAGGREGATEPREVOTESREQUEST,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryAggregatePrevotesRequest)
  })
_sym_db.RegisterMessage(QueryAggregatePrevotesRequest)

QueryAggregatePrevotesResponse = _reflection.GeneratedProtocolMessageType('QueryAggregatePrevotesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYAGGREGATEPREVOTESRESPONSE,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryAggregatePrevotesResponse)
  })
_sym_db.RegisterMessage(QueryAggregatePrevotesResponse)

QueryAggregateVoteRequest = _reflection.GeneratedProtocolMessageType('QueryAggregateVoteRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYAGGREGATEVOTEREQUEST,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryAggregateVoteRequest)
  })
_sym_db.RegisterMessage(QueryAggregateVoteRequest)

QueryAggregateVoteResponse = _reflection.GeneratedProtocolMessageType('QueryAggregateVoteResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYAGGREGATEVOTERESPONSE,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryAggregateVoteResponse)
  })
_sym_db.RegisterMessage(QueryAggregateVoteResponse)

QueryAggregateVotesRequest = _reflection.GeneratedProtocolMessageType('QueryAggregateVotesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYAGGREGATEVOTESREQUEST,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryAggregateVotesRequest)
  })
_sym_db.RegisterMessage(QueryAggregateVotesRequest)

QueryAggregateVotesResponse = _reflection.GeneratedProtocolMessageType('QueryAggregateVotesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYAGGREGATEVOTESRESPONSE,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryAggregateVotesResponse)
  })
_sym_db.RegisterMessage(QueryAggregateVotesResponse)

QueryParamsRequest = _reflection.GeneratedProtocolMessageType('QueryParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSREQUEST,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryParamsRequest)
  })
_sym_db.RegisterMessage(QueryParamsRequest)

QueryParamsResponse = _reflection.GeneratedProtocolMessageType('QueryParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPARAMSRESPONSE,
  '__module__' : 'oracle.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.oracle.v1beta1.QueryParamsResponse)
  })
_sym_db.RegisterMessage(QueryParamsResponse)

_QUERY = DESCRIPTOR.services_by_name['Query']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z,github.com/NibiruChain/nibiru/x/oracle/types'
  _QUERYEXCHANGERATEREQUEST._options = None
  _QUERYEXCHANGERATEREQUEST._serialized_options = b'\350\240\037\000\210\240\037\000'
  _QUERYEXCHANGERATERESPONSE.fields_by_name['exchange_rate']._options = None
  _QUERYEXCHANGERATERESPONSE.fields_by_name['exchange_rate']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERYEXCHANGERATESRESPONSE.fields_by_name['exchange_rates']._options = None
  _QUERYEXCHANGERATESRESPONSE.fields_by_name['exchange_rates']._serialized_options = b'\252\337\037\022ExchangeRateTuples\310\336\037\000'
  _QUERYTOBINTAXREQUEST._options = None
  _QUERYTOBINTAXREQUEST._serialized_options = b'\350\240\037\000\210\240\037\000'
  _QUERYTOBINTAXRESPONSE.fields_by_name['tobin_tax']._options = None
  _QUERYTOBINTAXRESPONSE.fields_by_name['tobin_tax']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _QUERYTOBINTAXESRESPONSE.fields_by_name['tobin_taxes']._options = None
  _QUERYTOBINTAXESRESPONSE.fields_by_name['tobin_taxes']._serialized_options = b'\362\336\037\022yaml:\"tobin_taxes\"\252\337\037\010PairList\310\336\037\000'
  _QUERYFEEDERDELEGATIONREQUEST._options = None
  _QUERYFEEDERDELEGATIONREQUEST._serialized_options = b'\350\240\037\000\210\240\037\000'
  _QUERYMISSCOUNTERREQUEST._options = None
  _QUERYMISSCOUNTERREQUEST._serialized_options = b'\350\240\037\000\210\240\037\000'
  _QUERYAGGREGATEPREVOTEREQUEST._options = None
  _QUERYAGGREGATEPREVOTEREQUEST._serialized_options = b'\350\240\037\000\210\240\037\000'
  _QUERYAGGREGATEPREVOTERESPONSE.fields_by_name['aggregate_prevote']._options = None
  _QUERYAGGREGATEPREVOTERESPONSE.fields_by_name['aggregate_prevote']._serialized_options = b'\310\336\037\000'
  _QUERYAGGREGATEPREVOTESRESPONSE.fields_by_name['aggregate_prevotes']._options = None
  _QUERYAGGREGATEPREVOTESRESPONSE.fields_by_name['aggregate_prevotes']._serialized_options = b'\310\336\037\000'
  _QUERYAGGREGATEVOTEREQUEST._options = None
  _QUERYAGGREGATEVOTEREQUEST._serialized_options = b'\350\240\037\000\210\240\037\000'
  _QUERYAGGREGATEVOTERESPONSE.fields_by_name['aggregate_vote']._options = None
  _QUERYAGGREGATEVOTERESPONSE.fields_by_name['aggregate_vote']._serialized_options = b'\310\336\037\000'
  _QUERYAGGREGATEVOTESRESPONSE.fields_by_name['aggregate_votes']._options = None
  _QUERYAGGREGATEVOTESRESPONSE.fields_by_name['aggregate_votes']._serialized_options = b'\310\336\037\000'
  _QUERYPARAMSRESPONSE.fields_by_name['params']._options = None
  _QUERYPARAMSRESPONSE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _QUERY.methods_by_name['ExchangeRate']._options = None
  _QUERY.methods_by_name['ExchangeRate']._serialized_options = b'\202\323\344\223\0023\0221/nibiru/oracle/v1beta1/pairs/{pair}/exchange_rate'
  _QUERY.methods_by_name['ExchangeRates']._options = None
  _QUERY.methods_by_name['ExchangeRates']._serialized_options = b'\202\323\344\223\002-\022+/nibiru/oracle/v1beta1/pairs/exchange_rates'
  _QUERY.methods_by_name['TobinTax']._options = None
  _QUERY.methods_by_name['TobinTax']._serialized_options = b'\202\323\344\223\002/\022-/nibiru/oracle/v1beta1/pairs/{pair}/tobin_tax'
  _QUERY.methods_by_name['TobinTaxes']._options = None
  _QUERY.methods_by_name['TobinTaxes']._serialized_options = b'\202\323\344\223\002*\022(/nibiru/oracle/v1beta1/pairs/tobin_taxes'
  _QUERY.methods_by_name['Actives']._options = None
  _QUERY.methods_by_name['Actives']._serialized_options = b'\202\323\344\223\002&\022$/nibiru/oracle/v1beta1/pairs/actives'
  _QUERY.methods_by_name['VoteTargets']._options = None
  _QUERY.methods_by_name['VoteTargets']._serialized_options = b'\202\323\344\223\002+\022)/nibiru/oracle/v1beta1/pairs/vote_targets'
  _QUERY.methods_by_name['FeederDelegation']._options = None
  _QUERY.methods_by_name['FeederDelegation']._serialized_options = b'\202\323\344\223\002;\0229/nibiru/oracle/v1beta1/validators/{validator_addr}/feeder'
  _QUERY.methods_by_name['MissCounter']._options = None
  _QUERY.methods_by_name['MissCounter']._serialized_options = b'\202\323\344\223\0029\0227/nibiru/oracle/v1beta1/validators/{validator_addr}/miss'
  _QUERY.methods_by_name['AggregatePrevote']._options = None
  _QUERY.methods_by_name['AggregatePrevote']._serialized_options = b'\202\323\344\223\002F\022D/nibiru/oracle/v1beta1/validators/{validator_addr}/aggregate_prevote'
  _QUERY.methods_by_name['AggregatePrevotes']._options = None
  _QUERY.methods_by_name['AggregatePrevotes']._serialized_options = b'\202\323\344\223\0026\0224/nibiru/oracle/v1beta1/validators/aggregate_prevotes'
  _QUERY.methods_by_name['AggregateVote']._options = None
  _QUERY.methods_by_name['AggregateVote']._serialized_options = b'\202\323\344\223\002C\022A/nibiru/oracle/v1beta1/valdiators/{validator_addr}/aggregate_vote'
  _QUERY.methods_by_name['AggregateVotes']._options = None
  _QUERY.methods_by_name['AggregateVotes']._serialized_options = b'\202\323\344\223\0023\0221/nibiru/oracle/v1beta1/validators/aggregate_votes'
  _QUERY.methods_by_name['Params']._options = None
  _QUERY.methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\037\022\035/nibiru/oracle/v1beta1/params'
  _QUERYEXCHANGERATEREQUEST._serialized_start=166
  _QUERYEXCHANGERATEREQUEST._serialized_end=216
  _QUERYEXCHANGERATERESPONSE._serialized_start=218
  _QUERYEXCHANGERATERESPONSE._serialized_end=316
  _QUERYEXCHANGERATESREQUEST._serialized_start=318
  _QUERYEXCHANGERATESREQUEST._serialized_end=345
  _QUERYEXCHANGERATESRESPONSE._serialized_start=347
  _QUERYEXCHANGERATESRESPONSE._serialized_end=469
  _QUERYTOBINTAXREQUEST._serialized_start=471
  _QUERYTOBINTAXREQUEST._serialized_end=517
  _QUERYTOBINTAXRESPONSE._serialized_start=519
  _QUERYTOBINTAXRESPONSE._serialized_end=609
  _QUERYTOBINTAXESREQUEST._serialized_start=611
  _QUERYTOBINTAXESREQUEST._serialized_end=635
  _QUERYTOBINTAXESRESPONSE._serialized_start=637
  _QUERYTOBINTAXESRESPONSE._serialized_end=752
  _QUERYACTIVESREQUEST._serialized_start=754
  _QUERYACTIVESREQUEST._serialized_end=775
  _QUERYACTIVESRESPONSE._serialized_start=777
  _QUERYACTIVESRESPONSE._serialized_end=816
  _QUERYVOTETARGETSREQUEST._serialized_start=818
  _QUERYVOTETARGETSREQUEST._serialized_end=843
  _QUERYVOTETARGETSRESPONSE._serialized_start=845
  _QUERYVOTETARGETSRESPONSE._serialized_end=893
  _QUERYFEEDERDELEGATIONREQUEST._serialized_start=895
  _QUERYFEEDERDELEGATIONREQUEST._serialized_end=959
  _QUERYFEEDERDELEGATIONRESPONSE._serialized_start=961
  _QUERYFEEDERDELEGATIONRESPONSE._serialized_end=1013
  _QUERYMISSCOUNTERREQUEST._serialized_start=1015
  _QUERYMISSCOUNTERREQUEST._serialized_end=1074
  _QUERYMISSCOUNTERRESPONSE._serialized_start=1076
  _QUERYMISSCOUNTERRESPONSE._serialized_end=1124
  _QUERYAGGREGATEPREVOTEREQUEST._serialized_start=1126
  _QUERYAGGREGATEPREVOTEREQUEST._serialized_end=1190
  _QUERYAGGREGATEPREVOTERESPONSE._serialized_start=1192
  _QUERYAGGREGATEPREVOTERESPONSE._serialized_end=1309
  _QUERYAGGREGATEPREVOTESREQUEST._serialized_start=1311
  _QUERYAGGREGATEPREVOTESREQUEST._serialized_end=1342
  _QUERYAGGREGATEPREVOTESRESPONSE._serialized_start=1344
  _QUERYAGGREGATEPREVOTESRESPONSE._serialized_end=1463
  _QUERYAGGREGATEVOTEREQUEST._serialized_start=1465
  _QUERYAGGREGATEVOTEREQUEST._serialized_end=1526
  _QUERYAGGREGATEVOTERESPONSE._serialized_start=1528
  _QUERYAGGREGATEVOTERESPONSE._serialized_end=1636
  _QUERYAGGREGATEVOTESREQUEST._serialized_start=1638
  _QUERYAGGREGATEVOTESREQUEST._serialized_end=1666
  _QUERYAGGREGATEVOTESRESPONSE._serialized_start=1668
  _QUERYAGGREGATEVOTESRESPONSE._serialized_end=1778
  _QUERYPARAMSREQUEST._serialized_start=1780
  _QUERYPARAMSREQUEST._serialized_end=1800
  _QUERYPARAMSRESPONSE._serialized_start=1802
  _QUERYPARAMSRESPONSE._serialized_end=1876
  _QUERY._serialized_start=1879
  _QUERY._serialized_end=4147
# @@protoc_insertion_point(module_scope)
