# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vpool/v1/gov.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12vpool/v1/gov.proto\x12\x0fnibiru.vpool.v1\x1a\x14gogoproto/gogo.proto\"\xe4\x04\n\x12\x43reatePoolProposal\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04pair\x18\x03 \x01(\t\x12I\n\x11trade_limit_ratio\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12K\n\x13quote_asset_reserve\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12J\n\x12\x62\x61se_asset_reserve\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12O\n\x17\x66luctuation_limit_ratio\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12O\n\x17max_oracle_spread_ratio\x18\x08 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12P\n\x18maintenance_margin_ratio\x18\t \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x44\n\x0cmax_leverage\x18\n \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x42-Z+github.com/NibiruChain/nibiru/x/vpool/typesb\x06proto3')



_CREATEPOOLPROPOSAL = DESCRIPTOR.message_types_by_name['CreatePoolProposal']
CreatePoolProposal = _reflection.GeneratedProtocolMessageType('CreatePoolProposal', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPOOLPROPOSAL,
  '__module__' : 'vpool.v1.gov_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.vpool.v1.CreatePoolProposal)
  })
_sym_db.RegisterMessage(CreatePoolProposal)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/NibiruChain/nibiru/x/vpool/types'
  _CREATEPOOLPROPOSAL.fields_by_name['trade_limit_ratio']._options = None
  _CREATEPOOLPROPOSAL.fields_by_name['trade_limit_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _CREATEPOOLPROPOSAL.fields_by_name['quote_asset_reserve']._options = None
  _CREATEPOOLPROPOSAL.fields_by_name['quote_asset_reserve']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _CREATEPOOLPROPOSAL.fields_by_name['base_asset_reserve']._options = None
  _CREATEPOOLPROPOSAL.fields_by_name['base_asset_reserve']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _CREATEPOOLPROPOSAL.fields_by_name['fluctuation_limit_ratio']._options = None
  _CREATEPOOLPROPOSAL.fields_by_name['fluctuation_limit_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _CREATEPOOLPROPOSAL.fields_by_name['max_oracle_spread_ratio']._options = None
  _CREATEPOOLPROPOSAL.fields_by_name['max_oracle_spread_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _CREATEPOOLPROPOSAL.fields_by_name['maintenance_margin_ratio']._options = None
  _CREATEPOOLPROPOSAL.fields_by_name['maintenance_margin_ratio']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _CREATEPOOLPROPOSAL.fields_by_name['max_leverage']._options = None
  _CREATEPOOLPROPOSAL.fields_by_name['max_leverage']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _CREATEPOOLPROPOSAL._serialized_start=62
  _CREATEPOOLPROPOSAL._serialized_end=674
# @@protoc_insertion_point(module_scope)
