"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import cosmos.slashing.v1beta1.tx_pb2
import grpc

class MsgStub:
    """Msg defines the slashing Msg service."""
    def __init__(self, channel: grpc.Channel) -> None: ...
    Unjail: grpc.UnaryUnaryMultiCallable[
        cosmos.slashing.v1beta1.tx_pb2.MsgUnjail,
        cosmos.slashing.v1beta1.tx_pb2.MsgUnjailResponse]
    """Unjail defines a method for unjailing a jailed validator, thus returning
    them into the bonded validator set, so they can begin receiving provisions
    and rewards again.
    """


class MsgServicer(metaclass=abc.ABCMeta):
    """Msg defines the slashing Msg service."""
    @abc.abstractmethod
    def Unjail(self,
        request: cosmos.slashing.v1beta1.tx_pb2.MsgUnjail,
        context: grpc.ServicerContext,
    ) -> cosmos.slashing.v1beta1.tx_pb2.MsgUnjailResponse:
        """Unjail defines a method for unjailing a jailed validator, thus returning
        them into the bonded validator set, so they can begin receiving provisions
        and rewards again.
        """
        pass


def add_MsgServicer_to_server(servicer: MsgServicer, server: grpc.Server) -> None: ...
