# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pricefeed/snapshot.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18pricefeed/snapshot.proto\x12\x13nibiru.pricefeed.v1\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/api/annotations.proto\"u\n\rPriceSnapshot\x12\x0f\n\x07pair_id\x18\x01 \x01(\t\x12=\n\x05price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x14\n\x0ctimestamp_ms\x18\x03 \x01(\x03\x42\x39Z/github.com/NibiruChain/nibiru/x/pricefeed/types\xa8\xe2\x1e\x01\xe0\xe1\x1e\x01\x62\x06proto3')



_PRICESNAPSHOT = DESCRIPTOR.message_types_by_name['PriceSnapshot']
PriceSnapshot = _reflection.GeneratedProtocolMessageType('PriceSnapshot', (_message.Message,), {
  'DESCRIPTOR' : _PRICESNAPSHOT,
  '__module__' : 'pricefeed.snapshot_pb2'
  # @@protoc_insertion_point(class_scope:nibiru.pricefeed.v1.PriceSnapshot)
  })
_sym_db.RegisterMessage(PriceSnapshot)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/NibiruChain/nibiru/x/pricefeed/types\250\342\036\001\340\341\036\001'
  _PRICESNAPSHOT.fields_by_name['price']._options = None
  _PRICESNAPSHOT.fields_by_name['price']._serialized_options = b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000'
  _PRICESNAPSHOT._serialized_start=134
  _PRICESNAPSHOT._serialized_end=251
# @@protoc_insertion_point(module_scope)
