"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class GenericAuthorization(google.protobuf.message.Message):
    """GenericAuthorization gives the grantee unrestricted permissions to execute
    the provided method on behalf of the granter's account.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MSG_FIELD_NUMBER: builtins.int
    msg: typing.Text
    """Msg, identified by it's type URL, to grant unrestricted permissions to execute"""

    def __init__(self,
        *,
        msg: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["msg",b"msg"]) -> None: ...
global___GenericAuthorization = GenericAuthorization

class Grant(google.protobuf.message.Message):
    """Grant gives permissions to execute
    the provide method with expiration time.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AUTHORIZATION_FIELD_NUMBER: builtins.int
    EXPIRATION_FIELD_NUMBER: builtins.int
    @property
    def authorization(self) -> google.protobuf.any_pb2.Any: ...
    @property
    def expiration(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(self,
        *,
        authorization: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        expiration: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authorization",b"authorization","expiration",b"expiration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorization",b"authorization","expiration",b"expiration"]) -> None: ...
global___Grant = Grant

class GrantAuthorization(google.protobuf.message.Message):
    """GrantAuthorization extends a grant with both the addresses of the grantee and granter.
    It is used in genesis.proto and query.proto

    Since: cosmos-sdk 0.45.2
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    GRANTER_FIELD_NUMBER: builtins.int
    GRANTEE_FIELD_NUMBER: builtins.int
    AUTHORIZATION_FIELD_NUMBER: builtins.int
    EXPIRATION_FIELD_NUMBER: builtins.int
    granter: typing.Text
    grantee: typing.Text
    @property
    def authorization(self) -> google.protobuf.any_pb2.Any: ...
    @property
    def expiration(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    def __init__(self,
        *,
        granter: typing.Text = ...,
        grantee: typing.Text = ...,
        authorization: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        expiration: typing.Optional[google.protobuf.timestamp_pb2.Timestamp] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["authorization",b"authorization","expiration",b"expiration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["authorization",b"authorization","expiration",b"expiration","grantee",b"grantee","granter",b"granter"]) -> None: ...
global___GrantAuthorization = GrantAuthorization
