"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class MsgAggregateExchangeRatePrevote(google.protobuf.message.Message):
    """MsgAggregateExchangeRatePrevote represents a message to submit
    aggregate exchange rate prevote.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    HASH_FIELD_NUMBER: builtins.int
    FEEDER_FIELD_NUMBER: builtins.int
    VALIDATOR_FIELD_NUMBER: builtins.int
    hash: typing.Text
    feeder: typing.Text
    validator: typing.Text
    def __init__(self,
        *,
        hash: typing.Text = ...,
        feeder: typing.Text = ...,
        validator: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["feeder",b"feeder","hash",b"hash","validator",b"validator"]) -> None: ...
global___MsgAggregateExchangeRatePrevote = MsgAggregateExchangeRatePrevote

class MsgAggregateExchangeRatePrevoteResponse(google.protobuf.message.Message):
    """MsgAggregateExchangeRatePrevoteResponse defines the Msg/AggregateExchangeRatePrevote response type."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___MsgAggregateExchangeRatePrevoteResponse = MsgAggregateExchangeRatePrevoteResponse

class MsgAggregateExchangeRateVote(google.protobuf.message.Message):
    """MsgAggregateExchangeRateVote represents a message to submit
    aggregate exchange rate vote.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SALT_FIELD_NUMBER: builtins.int
    EXCHANGE_RATES_FIELD_NUMBER: builtins.int
    FEEDER_FIELD_NUMBER: builtins.int
    VALIDATOR_FIELD_NUMBER: builtins.int
    salt: typing.Text
    exchange_rates: typing.Text
    feeder: typing.Text
    validator: typing.Text
    def __init__(self,
        *,
        salt: typing.Text = ...,
        exchange_rates: typing.Text = ...,
        feeder: typing.Text = ...,
        validator: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exchange_rates",b"exchange_rates","feeder",b"feeder","salt",b"salt","validator",b"validator"]) -> None: ...
global___MsgAggregateExchangeRateVote = MsgAggregateExchangeRateVote

class MsgAggregateExchangeRateVoteResponse(google.protobuf.message.Message):
    """MsgAggregateExchangeRateVoteResponse defines the Msg/AggregateExchangeRateVote response type."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___MsgAggregateExchangeRateVoteResponse = MsgAggregateExchangeRateVoteResponse

class MsgDelegateFeedConsent(google.protobuf.message.Message):
    """MsgDelegateFeedConsent represents a message to
    delegate oracle voting rights to another address.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    OPERATOR_FIELD_NUMBER: builtins.int
    DELEGATE_FIELD_NUMBER: builtins.int
    operator: typing.Text
    delegate: typing.Text
    def __init__(self,
        *,
        operator: typing.Text = ...,
        delegate: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["delegate",b"delegate","operator",b"operator"]) -> None: ...
global___MsgDelegateFeedConsent = MsgDelegateFeedConsent

class MsgDelegateFeedConsentResponse(google.protobuf.message.Message):
    """MsgDelegateFeedConsentResponse defines the Msg/DelegateFeedConsent response type."""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___MsgDelegateFeedConsentResponse = MsgDelegateFeedConsentResponse
