"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import cosmos.base.v1beta1.coin_pb2
import google.protobuf.descriptor
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class EventTransfer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    COIN_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TO_FIELD_NUMBER: builtins.int
    @property
    def coin(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    to: typing.Text
    def __init__(self,
        *,
        coin: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        to: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["coin",b"coin"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["coin",b"coin","from",b"from","to",b"to"]) -> None: ...
global___EventTransfer = EventTransfer

class EventMintStable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AMOUNT_FIELD_NUMBER: builtins.int
    amount: typing.Text
    def __init__(self,
        *,
        amount: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount",b"amount"]) -> None: ...
global___EventMintStable = EventMintStable

class EventBurnStable(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AMOUNT_FIELD_NUMBER: builtins.int
    amount: typing.Text
    def __init__(self,
        *,
        amount: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount",b"amount"]) -> None: ...
global___EventBurnStable = EventBurnStable

class EventMintNIBI(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AMOUNT_FIELD_NUMBER: builtins.int
    amount: typing.Text
    def __init__(self,
        *,
        amount: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount",b"amount"]) -> None: ...
global___EventMintNIBI = EventMintNIBI

class EventBurnNIBI(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    AMOUNT_FIELD_NUMBER: builtins.int
    amount: typing.Text
    def __init__(self,
        *,
        amount: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["amount",b"amount"]) -> None: ...
global___EventBurnNIBI = EventBurnNIBI

class EventRecollateralize(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CALLER_FIELD_NUMBER: builtins.int
    IN_COIN_FIELD_NUMBER: builtins.int
    OUT_COIN_FIELD_NUMBER: builtins.int
    COLL_RATIO_FIELD_NUMBER: builtins.int
    caller: typing.Text
    @property
    def in_coin(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    @property
    def out_coin(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    coll_ratio: typing.Text
    def __init__(self,
        *,
        caller: typing.Text = ...,
        in_coin: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        out_coin: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        coll_ratio: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["in_coin",b"in_coin","out_coin",b"out_coin"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["caller",b"caller","coll_ratio",b"coll_ratio","in_coin",b"in_coin","out_coin",b"out_coin"]) -> None: ...
global___EventRecollateralize = EventRecollateralize

class EventBuyback(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CALLER_FIELD_NUMBER: builtins.int
    IN_COIN_FIELD_NUMBER: builtins.int
    OUT_COIN_FIELD_NUMBER: builtins.int
    COLL_RATIO_FIELD_NUMBER: builtins.int
    caller: typing.Text
    @property
    def in_coin(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    @property
    def out_coin(self) -> cosmos.base.v1beta1.coin_pb2.Coin: ...
    coll_ratio: typing.Text
    def __init__(self,
        *,
        caller: typing.Text = ...,
        in_coin: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        out_coin: typing.Optional[cosmos.base.v1beta1.coin_pb2.Coin] = ...,
        coll_ratio: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["in_coin",b"in_coin","out_coin",b"out_coin"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["caller",b"caller","coll_ratio",b"coll_ratio","in_coin",b"in_coin","out_coin",b"out_coin"]) -> None: ...
global___EventBuyback = EventBuyback
