# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['nibiru',
 'nibiru.clients',
 'nibiru.composers',
 'nibiru.proto',
 'nibiru.proto.common',
 'nibiru.proto.confio',
 'nibiru.proto.cosmos.auth.v1beta1',
 'nibiru.proto.cosmos.authz.v1beta1',
 'nibiru.proto.cosmos.bank.v1beta1',
 'nibiru.proto.cosmos.base.abci.v1beta1',
 'nibiru.proto.cosmos.base.kv.v1beta1',
 'nibiru.proto.cosmos.base.query.v1beta1',
 'nibiru.proto.cosmos.base.reflection.v1beta1',
 'nibiru.proto.cosmos.base.reflection.v2alpha1',
 'nibiru.proto.cosmos.base.snapshots.v1beta1',
 'nibiru.proto.cosmos.base.store.v1beta1',
 'nibiru.proto.cosmos.base.tendermint.v1beta1',
 'nibiru.proto.cosmos.base.v1beta1',
 'nibiru.proto.cosmos.capability.v1beta1',
 'nibiru.proto.cosmos.crisis.v1beta1',
 'nibiru.proto.cosmos.crypto.ed25519',
 'nibiru.proto.cosmos.crypto.multisig',
 'nibiru.proto.cosmos.crypto.multisig.v1beta1',
 'nibiru.proto.cosmos.crypto.secp256k1',
 'nibiru.proto.cosmos.crypto.secp256r1',
 'nibiru.proto.cosmos.distribution.v1beta1',
 'nibiru.proto.cosmos.evidence.v1beta1',
 'nibiru.proto.cosmos.feegrant.v1beta1',
 'nibiru.proto.cosmos.genutil.v1beta1',
 'nibiru.proto.cosmos.gov.v1beta1',
 'nibiru.proto.cosmos.mint.v1beta1',
 'nibiru.proto.cosmos.params.v1beta1',
 'nibiru.proto.cosmos.slashing.v1beta1',
 'nibiru.proto.cosmos.staking.v1beta1',
 'nibiru.proto.cosmos.tx.signing.v1beta1',
 'nibiru.proto.cosmos.tx.v1beta1',
 'nibiru.proto.cosmos.upgrade.v1beta1',
 'nibiru.proto.cosmos.vesting.v1beta1',
 'nibiru.proto.cosmos_proto',
 'nibiru.proto.dex.v1',
 'nibiru.proto.epochs',
 'nibiru.proto.gogoproto',
 'nibiru.proto.google.api',
 'nibiru.proto.google.protobuf',
 'nibiru.proto.incentivization.v1',
 'nibiru.proto.lockup.v1',
 'nibiru.proto.oracle.v1beta1',
 'nibiru.proto.perp.v1',
 'nibiru.proto.pricefeed',
 'nibiru.proto.stablecoin',
 'nibiru.proto.tendermint.abci',
 'nibiru.proto.tendermint.crypto',
 'nibiru.proto.tendermint.libs.bits',
 'nibiru.proto.tendermint.p2p',
 'nibiru.proto.tendermint.types',
 'nibiru.proto.tendermint.version',
 'nibiru.proto.vpool.v1',
 'nibiru.sdks',
 'nibiru.sdks.tx']

package_data = \
{'': ['*']}

install_requires = \
['aiocron>=1.8,<2.0',
 'aiohttp>=3.8.1,<4.0.0',
 'asyncio>=3.4.3,<4.0.0',
 'bech32>=1.2.0,<2.0.0',
 'bip32>=3.1,<4.0',
 'coincurve>=17.0.0,<18.0.0',
 'ecdsa>=0.18.0,<0.19.0',
 'eip712-structs>=1.1.0,<2.0.0',
 'grpcio>=1.48.0,<2.0.0',
 'hdwallets>=0.1.2,<0.2.0',
 'mnemonic>=0.20,<0.21',
 'protobuf==3.20.1',
 'pysha3>=1.0.2,<2.0.0',
 'pytest>=7.1.2,<8.0.0',
 'python-dotenv>=0.20.0,<0.21.0',
 'requests>=2.28.1,<3.0.0']

setup_kwargs = {
    'name': 'nibiru',
    'version': '0.0.14a1',
    'description': 'Python SDK for interacting with Nibiru.',
    'long_description': None,
    'author': 'Nibiru Chain',
    'author_email': 'you@example.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
